@@ -36,7 +36,7 @@
  * If the target pad is known at creation time, gst_ghost_pad_new() is the
  * function to use to get a ghost-pad. Otherwise one can use gst_ghost_pad_new_no_target()
  * to create the ghost-pad and use gst_ghost_pad_set_target() to establish the
- * accociation later on.
+ * association later on.
  *
  * Last reviewed on 2005-11-18 (0.9.5)
  */
@@ -383,9 +383,11 @@ static void
 gst_proxy_pad_dispose (GObject * object)
 {
   GstPad *pad = GST_PAD (object);
+  GstPad **target_p;
 
   GST_PROXY_LOCK (pad);
-  gst_object_replace ((GstObject **) & GST_PROXY_PAD_TARGET (pad), NULL);
+  target_p = &GST_PROXY_PAD_TARGET (pad);
+  gst_object_replace ((GstObject **) target_p, NULL);
   GST_PROXY_UNLOCK (pad);
 
   G_OBJECT_CLASS (gst_proxy_pad_parent_class)->dispose (object);
